pub struct FontGroup { /* private fields */ }Expand description
A FontGroup is a prioritised list of fonts for a given set of font styles. It is used by
TextRun to decide which font to render a character with. If none of the fonts listed in the
styles are suitable, a fallback font may be used.
Implementations
Sourceimpl FontGroup
impl FontGroup
Sourcepub fn find_by_codepoint(
&self,
font_context: &FontContext,
codepoint: char,
next_codepoint: Option<char>,
lang: XLang,
) -> Option<FontRef>
pub fn find_by_codepoint( &self, font_context: &FontContext, codepoint: char, next_codepoint: Option<char>, lang: XLang, ) -> Option<FontRef>
Finds the first font, or else the first fallback font, which contains a glyph for
codepoint. If no such font is found, returns the first available font or fallback font
(which will cause a “glyph not found” character to be rendered). If no font at all can be
found, returns None.
Sourcepub fn first(&self, font_context: &FontContext) -> Option<FontRef>
pub fn first(&self, font_context: &FontContext) -> Option<FontRef>
Find the first available font in the group, or the first available fallback font.