pub struct GlyphStore { /* private fields */ }Expand description
Stores the glyph data belonging to a text run.
Simple glyphs are stored inline in the entry_buffer, detailed glyphs are
stored as pointers into the detail_store.
+- GlyphStore --------------------------------+
| +---+---+---+---+---+---+---+ |
| entry_buffer: | | s | | s | | s | s | | d = detailed
| +-|-+---+-|-+---+-|-+---+---+ | s = simple
| | | | |
| | +---+-------+ |
| | | |
| +-V-+-V-+ |
| detail_store: | d | d | |
| +---+---+ |
+---------------------------------------------+Implementations
Sourceimpl GlyphStore
impl GlyphStore
pub fn total_advance(&self) -> Au
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Return the number of glyphs stored in this GlyphStore.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Whether or not this GlyphStore has any glyphs.
Sourcepub fn character_count(&self) -> usize
pub fn character_count(&self) -> usize
The number of characters (char) from the original string that produced this
GlyphStore.
Sourcepub fn is_whitespace(&self) -> bool
pub fn is_whitespace(&self) -> bool
Whether or not this GlyphStore is entirely whitepsace.
Sourcepub fn is_single_preserved_newline(&self) -> bool
pub fn is_single_preserved_newline(&self) -> bool
Whether or not this GlyphStore is a single preserved newline.
Sourcepub fn ends_with_whitespace(&self) -> bool
pub fn ends_with_whitespace(&self) -> bool
Whether or not this GlyphStore ends with whitespace.
Sourcepub fn total_word_separators(&self) -> usize
pub fn total_word_separators(&self) -> usize
The number of word separators in this GlyphStore.
Sourcepub fn total_characters(&self) -> usize
pub fn total_characters(&self) -> usize
The number of characters that were consumed to produce this GlyphStore. Some
characters correpond to more than one glyph and some glyphs correspond to more than
one character.
pub fn glyphs(&self) -> impl Iterator<Item = GlyphInfo<'_>> + use<'_>