pub struct SystemFontService { /* private fields */ }Expand description
The system font service. There is one of these for every Servo instance. This is a thread, responsible for reading the list of system fonts, handling requests to match against them, and ensuring that only one copy of system font data is loaded at a time.
Implementations
Sourceimpl SystemFontService
impl SystemFontService
pub fn spawn( paint_api: CrossProcessPaintApi, memory_profiler_sender: ProfilerChan, ) -> SystemFontServiceProxySender