pub struct Font {
pub metrics: Arc<FontMetrics>,
pub descriptor: FontDescriptor,
/* private fields */
}Fields
metrics: Arc<FontMetrics>descriptor: FontDescriptorImplementations
Sourceimpl Font
impl Font
pub fn new( template: FontTemplateRef, descriptor: FontDescriptor, data: Option<FontData>, synthesized_small_caps: Option<FontRef>, ) -> Result<Font, &'static str>
Sourcepub fn identifier(&self) -> FontIdentifier
pub fn identifier(&self) -> FontIdentifier
A unique identifier for the font, allowing comparison.
pub fn key( &self, painter_id: PainterId, font_context: &FontContext, ) -> FontInstanceKey
Sourcepub fn font_data_and_index(&self) -> Result<&FontDataAndIndex, FontDataError>
pub fn font_data_and_index(&self) -> Result<&FontDataAndIndex, FontDataError>
Return the data for this Font. Note that this is currently highly inefficient for system
fonts and should not be used except in legacy canvas code.
Sourceimpl Font
impl Font
pub fn shape_text( &self, text: &str, options: &ShapingOptions, ) -> Arc<GlyphStore>
Sourcepub fn can_do_fast_shaping(&self, text: &str, options: &ShapingOptions) -> bool
pub fn can_do_fast_shaping(&self, text: &str, options: &ShapingOptions) -> bool
Whether not a particular text and ShapingOptions combination can use
“fast shaping” ie shaping without Harfbuzz.
Note: This will eventually be removed.
pub fn glyph_index(&self, codepoint: char) -> Option<u32>
pub fn glyph_h_advance(&self, glyph_id: u32) -> f64
pub fn typographic_bounds(&self, glyph_id: u32) -> Rect<f32>
Sourcepub fn baseline(&self) -> Option<FontBaseline>
pub fn baseline(&self) -> Option<FontBaseline>
Get the FontBaseline for this font.