GlyphStore

Struct GlyphStore 

pub struct GlyphStore { /* private fields */ }
Stores the glyph data belonging to a text run.

Simple glyphs are stored inline in the entry_buffer, detailed glyphs are stored as pointers into the detail_store.

+- GlyphStore --------------------------------+
|               +---+---+---+---+---+---+---+ |
| entry_buffer: |   | s |   | s |   | s | s | |  d = detailed
|               +-|-+---+-|-+---+-|-+---+---+ |  s = simple
|                 |       |       |           |
|                 |   +---+-------+           |
|                 |   |                       |
|               +-V-+-V-+                     |
| detail_store: | d | d |                     |
|               +---+---+                     |
+---------------------------------------------+

Implementations

Source

impl GlyphStore

pub fn total_advance(&self) -> Au

pub fn len(&self) -> usize

Return the number of glyphs stored in this GlyphStore.

pub fn is_empty(&self) -> bool

Whether or not this GlyphStore has any glyphs.

pub fn character_count(&self) -> usize

The number of characters (char) from the original string that produced this GlyphStore.

pub fn is_whitespace(&self) -> bool

Whether or not this GlyphStore is entirely whitepsace.

pub fn is_single_preserved_newline(&self) -> bool

Whether or not this GlyphStore is a single preserved newline.

pub fn ends_with_whitespace(&self) -> bool

Whether or not this GlyphStore ends with whitespace.

pub fn total_word_separators(&self) -> usize

The number of word separators in this GlyphStore.

pub fn total_characters(&self) -> usize

The number of characters that were consumed to produce this GlyphStore. Some characters correpond to more than one glyph and some glyphs correspond to more than one character.

pub fn glyphs(&self) -> impl Iterator<Item = GlyphInfo<'_>> + use<'_>